@@ -18,7 +18,7 @@ import traceback
 from os.path import basename, normpath
 from typing import Any, Collection, Iterable, List, Optional, Set, Union
 
-from mitosheet.types import ColumnHeader, ColumnID, Operator, StateType
+from mitosheet.types import ColumnHeader, ColumnID, OperatorType, StateType
 
 
 class MitoError(Exception):
@@ -635,6 +635,7 @@ def make_exec_error(e: Exception) -> MitoError:
         error_modal=False
     )
 
+
 def make_upper_left_corner_value_not_found_error(value: Union[str, int, float, bool], error_modal: bool) -> MitoError:
     """
     Helper function for creating a upper_left_corner_value_not_found_error.
