@@ -1,9 +1,9 @@
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GNU Affero General Public License v3.0 License.
+
+
 
 from mitosheet.public.v1.sheet_functions import FUNCTIONS
 from mitosheet.public.v1.sheet_functions import *
-from mitosheet.public.v1.utils import flatten_column_header, deduplicate_column_headers
+from mitosheet.public.v1.utils import flatten_column_header
 from mitosheet.public.v1.sheet_functions.types import to_int_series, to_boolean_series, to_float_series, to_timedelta_series, get_datetime_format
 from mitosheet.public.v1.sheet_functions.types import *
 import pandas as pd
@@ -19,4 +19,4 @@ def register_analysis(analysis_name):
 
 
 # Forwards compatible functions
-from mitosheet.public.v2.excel_utils import get_table_range_from_upper_left_corner_value, get_read_excel_params_from_range, get_table_range, convert_csv_file_to_xlsx_file
\ No newline at end of file
+from mitosheet.public.v2.excel_utils import get_table_range_from_upper_left_corner_value, get_read_excel_params_from_range
\ No newline at end of file
