@@ -14,24 +14,19 @@ in more detail in docs/README.md.
 NOTE: This file is alphabetical order!
 """
 import functools
-from typing import Optional, Union
-
-import numpy as np
+from typing import Optional, Tuple, Union
 import pandas as pd
+import numpy as np
 
-from mitosheet.public.v1.sheet_functions.sheet_function_utils import (
-    fill_series_with_one_index, try_extend_series_to_index)
-from mitosheet.public.v1.sheet_functions.types.decorators import (
-    convert_arg_to_series_type, convert_args_to_series_type, fill_nans,
-    filter_nans, handle_sheet_function_errors)
-
+from mitosheet.public.v1.sheet_functions.types.decorators import fill_nans, filter_nans, convert_args_to_series_type, convert_arg_to_series_type, handle_sheet_function_errors
+from mitosheet.public.v1.sheet_functions.sheet_function_utils import try_extend_series_to_index, fill_series_with_one_index, fill_series_with_one_index
 
 @handle_sheet_function_errors
 @convert_arg_to_series_type(
     0,
     'float',
     'error',
-    ('default', np.nan)
+    ('default', np.NaN)
 )
 def ABS(series: pd.Series) -> pd.Series:
     """
@@ -56,7 +51,7 @@ def ABS(series: pd.Series) -> pd.Series:
 
 @handle_sheet_function_errors
 @filter_nans
-@convert_args_to_series_type('float', 'skip', ('default', np.nan))
+@convert_args_to_series_type('float', 'skip', ('default', np.NaN))
 def AVG(*argv: pd.Series) -> pd.Series:
     """
     {
@@ -92,13 +87,13 @@ def AVG(*argv: pd.Series) -> pd.Series:
     0,
     'float',
     'error',
-    ('default', np.nan)
+    ('default', np.NaN)
 )
 @convert_arg_to_series_type(
     1,
     'float',
     'error',
-    ('default', np.nan)
+    ('default', np.NaN)
 )
 def CORR(s1: pd.Series, s2: pd.Series) -> pd.Series:
     """
@@ -133,7 +128,7 @@ def CORR(s1: pd.Series, s2: pd.Series) -> pd.Series:
     0,
     'float',
     'error',
-    ('default', np.nan)
+    ('default', np.NaN)
 )
 def FLOAT(series: pd.Series) -> pd.Series:
     """
@@ -189,7 +184,7 @@ def INT(series: pd.Series) -> pd.Series:
     0,
     'float',
     'error',
-    ('default', np.nan)
+    ('default', np.NaN)
 )
 # We don't use the @filter_nans decorator because kurtosis ignores NaN values
 def KURT(series: pd.Series) -> pd.Series:
@@ -224,7 +219,7 @@ def KURT(series: pd.Series) -> pd.Series:
     0,
     'float',
     'error',
-    ('default', np.nan)
+    ('default', np.NaN)
 )
 def LOG(series: pd.Series, base: Optional[Union[int, float]]=None) -> pd.Series:
     """
@@ -354,7 +349,7 @@ def MULTIPLY(*argv: pd.Series) -> pd.Series:
     0,
     'float',
     'error',
-    ('default', np.nan)
+    ('default', np.NaN)
 )
 @convert_arg_to_series_type(
     1,
@@ -394,7 +389,7 @@ def POWER(series, power):
     0,
     'float',
     'error',
-    ('default', np.nan)
+    ('default', np.NaN)
 )
 @convert_arg_to_series_type(
     1,
@@ -443,7 +438,7 @@ def ROUND(series, decimals=None):
     0,
     'float',
     'error',
-    ('default', np.nan)
+    ('default', np.NaN)
 )
 # We don't use the @filter_nans decorator because skew ignores NaN values
 def SKEW(series: pd.Series) -> pd.Series:
@@ -508,7 +503,7 @@ def SUM(*argv: pd.Series) -> pd.Series:
     0,
     'float',
     'error',
-    ('default', np.nan)
+    ('default', np.NaN)
 )
 # We don't use the @filter_nans decorator because std ignores NaN values
 def STDEV(series: pd.Series) -> pd.Series:
@@ -543,7 +538,7 @@ def STDEV(series: pd.Series) -> pd.Series:
     0,
     'float',
     'error',
-    ('default', np.nan)
+    ('default', np.NaN)
 )
 def VALUE(series: pd.Series) -> pd.Series:
     """
@@ -572,7 +567,7 @@ def VALUE(series: pd.Series) -> pd.Series:
     0,
     'float',
     'error',
-    ('default', np.nan)
+    ('default', np.NaN)
 )
 def EXP(series: pd.Series) -> pd.Series:
     """
@@ -600,7 +595,7 @@ def EXP(series: pd.Series) -> pd.Series:
     0,
     'float',
     'error',
-    ('default', np.nan)
+    ('default', np.NaN)
 )
 # We don't use the @filter_nans decorator because var ignores NaN values
 def VAR(series: pd.Series) -> pd.Series:
