@@ -9,15 +9,14 @@ Contains all functions that can be used in a sheet that operate on dates.
 NOTE: This file is alphabetical order!
 """
 from datetime import datetime
-from packaging.version import Version
+from distutils.version import LooseVersion
+from typing import Optional
 
 import pandas as pd
 
 from mitosheet.public.v3.errors import handle_sheet_function_errors
 from mitosheet.public.v3.types.decorators import cast_values_in_arg_to_type
-from mitosheet.public.v3.types.sheet_function_types import (
-    DatetimeFunctionReturnType, DatetimeRestrictedInputType,
-    IntFunctionReturnType, StringFunctionReturnType)
+from mitosheet.public.v3.types.sheet_function_types import IntFunctionReturnType, DatetimeRestrictedInputType, DatetimeFunctionReturnType
 
 
 # Inspired by: https://stackoverflow.com/questions/69345845/why-does-dateoffset-rollback-not-work-the-way-i-expect-it-to-with-days-hours
@@ -44,7 +43,6 @@ def DATEVALUE(arg: DatetimeRestrictedInputType) -> DatetimeFunctionReturnType:
         "function": "DATEVALUE",
         "description": "Converts a given string to a date series.",
         "search_terms": ["datevalue", "date value", "date", "string to date", "datetime", "dtype", "convert"],
-        "category": "DATE",
         "examples": [
             "DATEVALUE(date_column)",
             "DATEVALUE('2012-12-22')"
@@ -68,7 +66,6 @@ def DAY(arg: DatetimeRestrictedInputType) -> IntFunctionReturnType:
         "function": "DAY",
         "description": "Returns the day of the month that a specific date falls on, as a number.",
         "search_terms": ["day", "date"],
-        "category": "DATE",
         "examples": [
             "DAY(date_column)",
             "DAY('2012-12-22')"
@@ -95,7 +92,6 @@ def ENDOFBUSINESSMONTH(arg: DatetimeRestrictedInputType) -> DatetimeFunctionRetu
         "function": "ENDOFBUSINESSMONTH",
         "description": "Given a date, returns the end of the buisness month. E.g. the last weekday.",
         "search_terms": ["business", "month", "eom", "eobm", "date", "workday", "end"],
-        "category": "DATE",
         "examples": [
             "ENDOFBUSINESSMONTH(date_column)",
             "ENDOFBUSINESSMONTH('2012-12-22')"
@@ -125,7 +121,6 @@ def ENDOFMONTH(arg: DatetimeRestrictedInputType) -> DatetimeFunctionReturnType:
         "function": "ENDOFMONTH",
         "description": "Given a date, returns the end of the month, as a date. E.g. input of 12-22-1997 will return 12-31-1997.",
         "search_terms": ["month", "eom", "date", "workday", "end", "eomonth"],
-        "category": "DATE",
         "examples": [
             "ENDOFMONTH(date_column)",
             "ENDOFMONTH('2012-12-22')"
@@ -154,7 +149,6 @@ def HOUR(arg: DatetimeRestrictedInputType) -> IntFunctionReturnType:
         "function": "HOUR",
         "description": "Returns the hour component of a specific date, as a number.",
         "search_terms": ["hour", "hr"],
-        "category": "DATE",
         "examples": [
             "HOUR(date_column)",
             "HOUR('2012-12-22 09:45:00')"
@@ -181,7 +175,6 @@ def MINUTE(arg: DatetimeRestrictedInputType) -> IntFunctionReturnType:
         "function": "MINUTE",
         "description": "Returns the minute component of a specific date, as a number.",
         "search_terms": ["minute", "min"],
-        "category": "DATE",
         "examples": [
             "MINUTE(date_column)",
             "MINUTE('2012-12-22 09:45:00')"
@@ -208,7 +201,6 @@ def MONTH(arg: DatetimeRestrictedInputType) -> IntFunctionReturnType:
         "function": "MONTH",
         "description": "Returns the month that a specific date falls in, as a number.",
         "search_terms": ["month", "date"],
-        "category": "DATE",
         "examples": [
             "MONTH(date_column)",
             "MONTH('2012-12-22')"
@@ -227,33 +219,6 @@ def MONTH(arg: DatetimeRestrictedInputType) -> IntFunctionReturnType:
     return arg.dt.month
 
 
-@cast_values_in_arg_to_type('arg', 'datetime')
-@handle_sheet_function_errors
-def MONTHNAME(arg: DatetimeRestrictedInputType) -> StringFunctionReturnType:
-    """
-    {
-        "function": "MONTHNAME",
-        "description": "Returns the month that a specific date falls in, as Jan, Feb, Mar, etc.",
-        "search_terms": ["month", "monthname", "date"],
-        "category": "DATE",
-        "examples": [
-            "MONTHNAME(date_column)",
-            "MONTHNAME('2012-12-22')"
-        ],
-        "syntax": "MONTHNAME(date)",
-        "syntax_elements": [{
-                "element": "date",
-                "description": "The date or date series to get the month of."
-            }
-        ]
-    }
-    """
-    if isinstance(arg, datetime) or isinstance(arg, pd.Timestamp):
-        return arg.strftime('%b')
-
-    return arg.dt.strftime('%b')
-
-
 @cast_values_in_arg_to_type('arg', 'datetime')
 @handle_sheet_function_errors
 def QUARTER(arg: DatetimeRestrictedInputType) -> IntFunctionReturnType:
@@ -262,7 +227,6 @@ def QUARTER(arg: DatetimeRestrictedInputType) -> IntFunctionReturnType:
         "function": "QUARTER",
         "description": "Returns the quarter (1-4) that a specific date falls in, as a number.",
         "search_terms": ["quarter"],
-        "category": "DATE",
         "examples": [
             "QUARTER(date_column)",
             "QUARTER('2012-12-22')"
@@ -291,7 +255,6 @@ def STARTOFBUSINESSMONTH(arg: DatetimeRestrictedInputType) -> DatetimeFunctionRe
         "function": "STARTOFBUSINESSMONTH",
         "description": "Given a date, returns the most recent start of the business month, as a state. E.g. the first weekday.",
         "search_terms": ["business", "month", "SOM", "SOBM", "date", "start"],
-        "category": "DATE",
         "examples": [
             "STARTOFBUSINESSMONTH(date_column)",
             "STARTOFBUSINESSMONTH('2012-12-22 09:23:05')"
@@ -320,7 +283,6 @@ def STARTOFMONTH(arg: DatetimeRestrictedInputType) -> DatetimeFunctionReturnType
         "function": "STARTOFMONTH",
         "description": "Given a date, returns the start of the month, as a date. E.g. input of 12-22-1997 will return 12-1-1997.",
         "search_terms": ["month", "SOM", "date", "start"],
-        "category": "DATE",
         "examples": [
             "STARTOFMONTH(date_column)",
             "STARTOFMONTH('2012-12-22 09:23:05')"
@@ -350,7 +312,6 @@ def STRIPTIMETOMINUTES(arg: DatetimeRestrictedInputType) -> DatetimeFunctionRetu
         "function": "STRIPTIMETOMINUTES",
         "description": "Returns the date with a seconds component of 00.",
         "search_terms": ["time", "date", "minutes", "strip"],
-        "category": "DATE",
         "examples": [
             "STRIPTIMETOMINUTES(date_column)",
             "STRIPTIMETOMINUTES('2012-12-22 09:23:05')"
@@ -379,7 +340,6 @@ def STRIPTIMETOHOURS(arg: DatetimeRestrictedInputType) -> DatetimeFunctionReturn
         "function": "STRIPTIMETOHOURS",
         "description": "Returns the date with a seconds and minutes component of 00:00.",
         "search_terms": ["time", "date", "hours", "strip"],
-        "category": "DATE",
         "examples": [
             "STRIPTIMETOHOURS(date_column)",
             "STRIPTIMETOHOURS('2012-12-22 09:23:05')"
@@ -408,7 +368,6 @@ def STRIPTIMETODAYS(arg: DatetimeRestrictedInputType) -> DatetimeFunctionReturnT
         "function": "STRIPTIMETODAYS",
         "description": "Returns the date with a seconds, minutes, and hours component of 00:00:00.",
         "search_terms": ["time", "date", "days", "strip"],
-        "category": "DATE",
         "examples": [
             "STRIPTIMETODAYS(date_column)",
             "STRIPTIMETODAYS('2012-12-22 09:23:05')"
@@ -437,7 +396,6 @@ def STRIPTIMETOMONTHS(arg: DatetimeRestrictedInputType) -> DatetimeFunctionRetur
         "function": "STRIPTIMETOMONTHS",
         "description": "Returns the date adjusted to the start of the month.",
         "search_terms": ["time", "date", "months", "strip"],
-        "category": "DATE",
         "examples": [
             "STRIPTIMETOMONTHS(date_column)",
             "STRIPTIMETOMONTHS('2012-12-22 09:23:05')"
@@ -457,22 +415,7 @@ def STRIPTIMETOMONTHS(arg: DatetimeRestrictedInputType) -> DatetimeFunctionRetur
     
     return arg.dt.floor('D') - pd.tseries.offsets.MonthBegin()
 
-@handle_sheet_function_errors
-def TODAY() -> DatetimeFunctionReturnType:
-    """
-    {
-        "function": "TODAY",
-        "description": "Returns the datetime value for the current date.",
-        "search_terms": ["today"],
-        "category": "DATE",
-        "examples": [
-            "TODAY()"
-        ],
-        "syntax": "TODAY()",
-        "syntax_elements": []
-    }
-    """
-    return pd.to_datetime('today').normalize()
+
 
 @cast_values_in_arg_to_type('arg', 'datetime')
 @handle_sheet_function_errors
@@ -482,7 +425,6 @@ def STRIPTIMETOYEARS(arg: DatetimeRestrictedInputType) -> DatetimeFunctionReturn
         "function": "STRIPTIMETOYEARS",
         "description": "Returns the date adjusted to the start of the year.",
         "search_terms": ["time", "date", "years", "strip"],
-        "category": "DATE",
         "examples": [
             "STRIPTIMETOYEARS(date_column)",
             "STRIPTIMETOYEARS('2012-12-22 09:23:05')"
@@ -511,7 +453,6 @@ def SECOND(arg: DatetimeRestrictedInputType) -> IntFunctionReturnType:
         "function": "SECOND",
         "description": "Returns the seconds component of a specific date, as a number.",
         "search_terms": ["second", "sec"],
-        "category": "DATE",
         "examples": [
             "SECOND(date_column)",
             "SECOND('2012-12-22 09:23:05')"
@@ -540,7 +481,6 @@ def WEEK(arg: DatetimeRestrictedInputType) -> IntFunctionReturnType:
         "function": "WEEK",
         "description": "Returns the week (1-52) of a specific date, as a number.",
         "search_terms": ["week", "1", "52"],
-        "category": "DATE",
         "examples": [
             "WEEK(date_column)",
             "WEEK('2012-12-22 09:23:05')"
@@ -559,7 +499,7 @@ def WEEK(arg: DatetimeRestrictedInputType) -> IntFunctionReturnType:
         return arg.week
 
     # Handle if we're on pandas version < 1.1, where isocalendar() is not available
-    if Version(pd.__version__) < Version('1.1'):
+    if LooseVersion(pd.__version__) < LooseVersion('1.1'):
         return arg.dt.week
     
     return arg.dt.isocalendar().week
@@ -573,7 +513,6 @@ def WEEKDAY(arg: DatetimeRestrictedInputType) -> IntFunctionReturnType:
         "function": "WEEKDAY",
         "description": "Returns the day of the week that a specific date falls on. 1-7 corresponds to Monday-Sunday.",
         "search_terms": ["weekday", "monday", "tuesday", "wednesday", "thursday", "friday", "saturday", "sunday"],
-        "category": "DATE",
         "examples": [
             "WEEKDAY(date_column)",
             "WEEKDAY('2012-12-22')"
@@ -602,7 +541,6 @@ def YEAR(arg: DatetimeRestrictedInputType) -> IntFunctionReturnType:
         "function": "YEAR",
         "description": "Returns the day of the year that a specific date falls in, as a number.",
         "search_terms": ["year", "date"],
-        "category": "DATE",
         "examples": [
             "YEAR(date_column)",
             "YEAR('2012-12-22')"
@@ -630,7 +568,6 @@ DATE_FUNCTIONS = {
     'ENDOFMONTH': ENDOFMONTH,
     'HOUR': HOUR,
     'MONTH': MONTH,
-    'MONTHNAME': MONTHNAME,
     'MINUTE': MINUTE,
     'QUARTER': QUARTER,
     'SECOND': SECOND,
@@ -641,7 +578,6 @@ DATE_FUNCTIONS = {
     'STRIPTIMETODAYS': STRIPTIMETODAYS,
     'STRIPTIMETOMONTHS': STRIPTIMETOMONTHS,
     'STRIPTIMETOYEARS': STRIPTIMETOYEARS,
-    'TODAY': TODAY,
     'WEEK': WEEK,
     'WEEKDAY': WEEKDAY,
     'YEAR': YEAR,
