@@ -1,8 +1,9 @@
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GNU Affero General Public License v3.0 License.
+
+
+
 
 from datetime import datetime, timedelta
-from typing import Union
+from typing import Type, Union
 
 import pandas as pd
 
@@ -30,7 +31,6 @@ DatetimeInputType = Union[pd.DataFrame, RollingRange, DatetimeRestrictedInputTyp
 AnyPrimitiveInputType = Union[str, int, float, bool, datetime, timedelta]
 AnyPrimitiveOrSeriesInputType = Union[AnyPrimitiveInputType, pd.Series]
 
-IfsInputType = Union[pd.Series, AnyPrimitiveOrSeriesInputType]
 
 # Return types
 StringFunctionReturnType = Union[pd.Series, str]
