@@ -6,10 +6,10 @@
 
 from mitosheet.saved_analyses.save_utils import (
     read_and_upgrade_analysis, write_analysis,
-    delete_saved_analysis, rename_saved_analysis, register_analysis,
+    delete_saved_analysis, rename_saved_analysis, 
     _get_all_analysis_filenames, _delete_analyses,
-    SAVED_ANALYSIS_FOLDER, write_analysis, read_analysis,
-    make_steps_json_obj
+    SAVED_ANALYSIS_FOLDER, read_analysis,
+    make_steps_json_obj, get_analysis_exists
 )
 from mitosheet.saved_analyses.upgrade import is_prev_version
-from mitosheet.saved_analyses.upgrade import upgrade_saved_analysis_to_current_version
\ No newline at end of file
+from mitosheet.saved_analyses.upgrade import upgrade_saved_analysis_to_current_version
