@@ -47,10 +47,11 @@ from mitosheet.saved_analyses.step_upgraders.set_dataframe_format import \
     upgrade_set_dataframe_format_1_to_2
 from mitosheet.saved_analyses.step_upgraders.simple_import import \
     upgrade_simple_import_1_to_2_and_rename
+from mitosheet.saved_analyses.step_upgraders.snowflake_import import upgrade_snowflake_import_1_to_2
 from mitosheet.saved_analyses.step_upgraders.sort import upgrade_sort_1_to_2
 from mitosheet.saved_analyses.step_upgraders.utils_rename_column_headers import \
     INITIAL_BULK_OLD_RENAME_STEP
-from mitosheet.saved_analyses.step_upgraders.excel_range_import import upgrade_excel_range_import_1_to_2
+from mitosheet.saved_analyses.step_upgraders.excel_range_import import upgrade_excel_range_import_1_to_2, upgrade_excel_range_import_2_to_3
 from mitosheet.utils import is_prev_version
 
 """
@@ -140,7 +141,11 @@ STEP_UPGRADES_FUNCTION_MAPPING_NEW_FORMAT = {
         1: upgrade_set_dataframe_format_1_to_2
     },
     'excel_range_import': {
-        1: upgrade_excel_range_import_1_to_2
+        1: upgrade_excel_range_import_1_to_2,
+        2: upgrade_excel_range_import_2_to_3
+    },
+    'snowflake_import': {
+        1: upgrade_snowflake_import_1_to_2
     }
 }
 
