@@ -10,19 +10,14 @@ import pandas as pd
 from mitosheet.code_chunks.code_chunk import CodeChunk
 from mitosheet.code_chunks.step_performers.column_steps.change_column_dtype_code_chunk import ChangeColumnDtypeCodeChunk
 
-from mitosheet.errors import get_recent_traceback, make_invalid_column_type_change_error, raise_error_if_column_ids_do_not_exist
-from mitosheet.sheet_functions.types import to_int_series
-from mitosheet.sheet_functions.types.to_boolean_series import to_boolean_series
-from mitosheet.sheet_functions.types.to_float_series import to_float_series
-from mitosheet.sheet_functions.types.to_timedelta_series import \
-    to_timedelta_series
-from mitosheet.sheet_functions.types.utils import (get_datetime_format,
-                                                   is_bool_dtype,
+from mitosheet.errors import make_invalid_column_type_change_error, raise_error_if_column_ids_do_not_exist
+from mitosheet.is_type_utils import (is_bool_dtype,
                                                    is_datetime_dtype,
                                                    is_float_dtype,
                                                    is_int_dtype, is_number_dtype,
                                                    is_string_dtype,
                                                    is_timedelta_dtype)
+from mitosheet.public.v1.sheet_functions.types.utils import get_to_datetime_params
 from mitosheet.state import State
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.step_performers.utils import get_param
@@ -39,7 +34,7 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
 
     @classmethod
     def step_version(cls) -> int:
-        return 3
+        return 4
 
     @classmethod
     def step_type(cls) -> str:
@@ -66,6 +61,7 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
         column_ids: List[ColumnID] = get_param(params, 'column_ids')
         old_dtypes: Dict[ColumnID, str] = get_param(params, 'old_dtypes')
         new_dtype: str = get_param(params, 'new_dtype')
+        public_interface_version: str = get_param(params, 'public_interface_version')
 
         raise_error_if_column_ids_do_not_exist(
             'change column dtype',
@@ -74,11 +70,20 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
             column_ids
         )
 
+        if public_interface_version == 1:
+            from mitosheet.public.v1 import to_int_series, to_boolean_series, to_float_series, to_timedelta_series, get_datetime_format
+        elif public_interface_version == 2:
+            from mitosheet.public.v2 import to_int_series, to_boolean_series, to_float_series, to_timedelta_series, get_datetime_format
+        elif public_interface_version == 3:
+            from mitosheet.public.v3 import to_int_series, to_boolean_series, to_float_series, to_timedelta_series, get_datetime_format
+        else:
+            raise Exception(f'Please add support for public_interface_version={public_interface_version}')
+
         post_state = prev_state.copy(deep_sheet_indexes=[sheet_index])
         pandas_processing_time: float = 0
 
         changed_column_ids: List[ColumnID] = []
-        datetime_formats: Dict[ColumnID, Optional[str]] = {}
+        to_datetime_params_map: Dict[ColumnID, Dict[str, Any]] = {}
         for column_id in column_ids:
 
             old_dtype = old_dtypes[column_id]
@@ -156,25 +161,15 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
                     elif is_string_dtype(new_dtype):
                         changed_this_column = False
                     elif is_datetime_dtype(new_dtype):
-                        # Guess the datetime format to the best of Pandas abilities
-                        datetime_format = get_datetime_format(column)
-
-                        # Save the datetime_format for use in the code chunk
-                        datetime_formats[column_id] = datetime_format
-
-                        # If it's None, then infer_datetime_format is enough to figure it out
-                        if datetime_format is not None:
-                            new_column = pd.to_datetime(
-                                column,
-                                format=datetime_format,
-                                errors='coerce'
-                            )
-                        else:
-                            new_column = pd.to_datetime(
-                                column,
-                                infer_datetime_format=True,
-                                errors='coerce'
-                            )
+                        # We need to detect the correct params to pass to the to_datetime function, and save them for use in the code chunk
+                        to_datetime_params = get_to_datetime_params(column)
+                        to_datetime_params_map[column_id] = to_datetime_params
+                        
+                        new_column = pd.to_datetime(
+                            column,
+                            errors='coerce',
+                            **to_datetime_params
+                        )
                     elif is_timedelta_dtype(new_dtype):
                         new_column = to_timedelta_series(column)
                 elif is_datetime_dtype(old_dtype):
@@ -238,8 +233,8 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
             'changed_column_ids': changed_column_ids
         }
 
-        if len(datetime_formats) > 0:
-            execution_data['datetime_formats'] = datetime_formats
+        if len(to_datetime_params_map) > 0:
+            execution_data['to_datetime_params_map'] = to_datetime_params_map
 
         return post_state, execution_data
         
@@ -253,7 +248,17 @@ class ChangeColumnDtypeStepPerformer(StepPerformer):
         execution_data: Optional[Dict[str, Any]],
     ) -> List[CodeChunk]:
         return [
-            ChangeColumnDtypeCodeChunk(prev_state, post_state, params, execution_data)
+            ChangeColumnDtypeCodeChunk(
+                prev_state, 
+                post_state, 
+                get_param(params, 'sheet_index'),
+                get_param(params, 'column_ids'),
+                get_param(params, 'old_dtypes'),
+                get_param(params, 'new_dtype'),
+                get_param(execution_data if execution_data is not None else {}, 'changed_column_ids'),
+                execution_data.get('to_datetime_params_map', None) if execution_data is not None else None,
+                get_param(params, 'public_interface_version')
+            )
         ]
 
     @classmethod
