@@ -21,9 +21,8 @@ from mitosheet.step_performers.graph_steps.graph_utils import (
     STRIP,
     VIOLIN,
     get_graph_title,
-    param_dict_to_code,
 )
-from mitosheet.transpiler.transpile_utils import column_header_list_to_transpiled_code, column_header_to_transpiled_code
+from mitosheet.transpiler.transpile_utils import param_dict_to_code
 from mitosheet.types import ColumnHeader
 
 DO_NOT_CHANGE_PAPER_BGCOLOR_DEFAULT = '#FFFFFF'
@@ -554,8 +553,4 @@ def get_plotly_express_graph_code(
         graph_styling_code(graph_type, all_column_headers, is_safety_filter_applied, graph_styling_params)
     )
 
-    # We use fig.show(renderer="iframe") which works in both JLab 2 & 3
-    # and renders in line,
-    code.append('fig.show(renderer="iframe")')
-
     return "\n".join(code)
